"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getProtocols = void 0;
var apollo_server_micro_1 = require("apollo-server-micro");
var queryMedicalDb_1 = require("../queryMedicalDb");
var getProtocols = function (_a) {
    var shortname = _a.shortname;
    return __awaiter(void 0, void 0, void 0, function () {
        var drugs;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0: return [4 /*yield*/, (0, queryMedicalDb_1.callMedicalDb)(queryMedicalDb_1.protocolsBody, {
                        shortname: shortname,
                    })];
                case 1:
                    drugs = (_b.sent()).drugs;
                    if (drugs.length === 0) {
                        throw new apollo_server_micro_1.ApolloError("Error: There is no drug with this shortname.");
                    }
                    return [2 /*return*/, drugs
                            .map(function (_a) {
                            var form = _a.form, dose = _a.dose, conditions = _a.conditions;
                            return {
                                form: form,
                                dose: dose,
                                protocols: getProtocolsFromConditions(conditions),
                            };
                        })
                            .filter(function (_a) {
                            var protocols = _a.protocols;
                            return !!protocols;
                        })];
            }
        });
    });
};
exports.getProtocols = getProtocols;
var getProtocolsFromConditions = function (conditions) {
    if (!conditions) {
        return null;
    }
    var uri = conditions.uri, summary = conditions.summary, prescription = conditions.prescription, first_issuance = conditions.first_issuance, renewal = conditions.renewal;
    return {
        uri: uri,
        summary: summary,
        prescription: getPrescription(prescription),
        firstIssuance: getFirstInsuance(first_issuance),
        renewal: getRenewal(renewal),
    };
};
var getPrescription = function (presciption) {
    if (!presciption ||
        Object.values(presciption).every(function (value) { return value == null; })) {
        return null;
    }
    var base_content = presciption.base_content, validity_initial_hospital_prescription = presciption.validity_initial_hospital_prescription, maximum_prescription_period = presciption.maximum_prescription_period, prescription_reserved = presciption.prescription_reserved, monitoring_during_treatment = presciption.monitoring_during_treatment, hospital_prescription = presciption.hospital_prescription, exception_drugs = presciption.exception_drugs, archives = presciption.archives;
    return {
        baseContent: base_content,
        validityInitialHospitalPrescription: validity_initial_hospital_prescription,
        maximumPrescriptionPeriod: maximum_prescription_period,
        prescriptionReserved: prescription_reserved,
        monitoringDuringTreatment: monitoring_during_treatment,
        hospitalPrescription: hospital_prescription,
        exceptionDrugs: exception_drugs,
        archives: archives,
    };
};
var getFirstInsuance = function (firstIssuance) {
    if (!firstIssuance ||
        Object.values(firstIssuance).every(function (value) { return value == null; })) {
        return null;
    }
    var base_content = firstIssuance.base_content, prescription_support = firstIssuance.prescription_support, time_limit = firstIssuance.time_limit, duration_treatment = firstIssuance.duration_treatment;
    return {
        baseContent: base_content,
        prescriptionSupport: prescription_support,
        timeLimit: time_limit,
        durationTreatment: duration_treatment,
    };
};
var getRenewal = function (renewal) {
    if (!renewal || Object.values(renewal).every(function (value) { return value == null; })) {
        return null;
    }
    var base_content = renewal.base_content, prescription_support = renewal.prescription_support;
    return {
        baseContent: base_content,
        prescriptionSupport: prescription_support,
    };
};
