import { ApolloError } from "apollo-server-micro";
import { callMedicalDb, contraindicationsBody } from "../queryMedicalDb";
import { FormDoseAndContraindications, DTOContraindicationsResponse } from "../types";

export const getContraindications = async ({
  shortname,
}: {
  shortname: string;
}): Promise<FormDoseAndContraindications[]> => {
  const { drugs } = (await callMedicalDb(contraindicationsBody, {
    shortname,
  })) as unknown as DTOContraindicationsResponse;

  if (drugs.length === 0) {
    throw new ApolloError(`Error: There is no drug with this shortname.`);
  }

  return drugs.map(
    ({ form, dose, contraindications }) => {
      return {
        dose,
        form,
        contraindications: contraindications.map(
          ({ label, level, comment, other_comment, text }) => {
            return {
              label,
              level,
              comment: comment || [],
              other_comment: other_comment || [],
              text: text || [],
            };
          }
        ),
      };
    }
  );
};
