import { ApolloError } from "apollo-server-micro";
import {
  callMedicalDb,
  indicationsAndOtherDocumentedUsagesBody,
} from "../queryMedicalDb";
import {
  DTOIndication,
  DTOIndicationsAndOtherDocumentedUsages,
  Indication,
  FormDoseIndicationsAndUnofficialIndications,
} from "../types";

export const getIndicationsAndOtherDocumentedUsages = async ({
  shortname,
}: {
  shortname: string;
}): Promise<FormDoseIndicationsAndUnofficialIndications[]> => {
  const { drugs } = (await callMedicalDb(
    indicationsAndOtherDocumentedUsagesBody,
    {
      shortname,
    }
  )) as unknown as DTOIndicationsAndOtherDocumentedUsages;

  if (drugs.length === 0) {
    throw new ApolloError(
      `Error: There is no drug with this shortname.`
    );
  }

  return drugs.map(({ form, dose, indications, unofficial_indications }) => {
    return {
      form,
      dose,
      indications: indications.map(getFormedIndication),
      unofficialIndications: unofficial_indications,
    };
  });
};

const getFormedIndication = (indications: DTOIndication): Indication => {
  const { disease, text, comments, nature_comments, types, level, smr, cim10 } =
    indications;
  const excludes = [" OU", "  OU", " ET/OU", "  ET/OU"];
  const typesCommentsAndNatureComments = [
    ...types,
    ...(comments ?? []),
    ...nature_comments.map(({ name }) => name),
  ].filter((b) => !excludes.includes(b) && b.indexOf("Cf.") !== 0);

  const cim10Codes = cim10?.reduce((acc, curr) => {
    if (
      curr.code?.length &&
      curr.code !== "." &&
      curr.code !== ".." &&
      curr.code !== "..."
    ) {
      if (curr.label?.length) {
        acc.push(`${curr.code} (${curr.label})`);
      } else {
        acc.push(`${curr.code}`);
      }
    }
    return acc;
  }, []);

  return {
    disease,
    typesCommentsAndNatureComments,
    text,
    level,
    smr,
    cim10Codes,
  };
};
