import { ApolloError } from "apollo-server-micro";
import { callMedicalDb, pharmacologyBody } from "../queryMedicalDb";
import {
  DTOEtiology,
  DTOPharmacologyResponse,
  Etiology,
  FormDoseAndPharmacology,
} from "../types";

export const getPharmacology = async ({
  shortname,
}: {
  shortname: string;
}): Promise<FormDoseAndPharmacology[]> => {
  const { drugs } = (await callMedicalDb(pharmacologyBody, {
    shortname,
  })) as unknown as DTOPharmacologyResponse;

  if (drugs.length === 0) {
    throw new ApolloError(`Error: There is no drug with this shortname.`);
  }

  return drugs.map(
    ({ form, dose, pharmacodynamics, pharmacokinetics, etiology }) => {
      return {
        form,
        dose,
        pharmacodynamics: pharmacodynamics?.[0]?.description,
        pharmacokinetics: pharmacokinetics?.[0]?.description,
        etiology: getEtiology(etiology),
      };
    }
  );
};

const getEtiology = (etiology: DTOEtiology[] | undefined): Etiology => {
  if (!etiology || etiology.length === 0) {
    return undefined;
  }
  const {
    intro,
    usually_sensitive,
    moderate_sensitive,
    inconsistently_sensitive,
    resistant,
  } = etiology[0];
  return {
    intro,
    usuallySensitive: usually_sensitive,
    moderateSensitive: moderate_sensitive,
    inconsistentlySensitive: inconsistently_sensitive,
    resistantSensitive: resistant,
  };
};
