import { ApolloError } from "apollo-server-micro";
import { callMedicalDb, sideEffectsBody } from "../queryMedicalDb";
import {
  DTOSideEffectsResponse,
  FormDoseAndSideEffectsCategory,
} from "../types";

export const getSideEffects = async ({
  shortname,
}: {
  shortname: string;
}): Promise<FormDoseAndSideEffectsCategory[]> => {
  const { drugs } = (await callMedicalDb(sideEffectsBody, {
    shortname,
  })) as unknown as DTOSideEffectsResponse;

  if (drugs.length === 0) {
    throw new ApolloError(`Error: There is no drug with this shortname.`);
  }

  return drugs.map(({ form, dose, side_effects_categories}) => {
    return {
      form,
      dose,
      sideEffectsCategories: side_effects_categories.map(
        ({
          category,
          severity,
          severity_category,
          frequency,
          frequency_string,
          frequency_comment,
          behaviour,
          behaviour_comment,
          occurence_time,
          occurence_comment,
          favoring_factors,
          other_favoring_factors,
          effects,
        }) => {
          return {
            category,
            severity,
            severityCategory: severity_category,
            frequency,
            frequencyString: frequency_string,
            frequencyComment: frequency_comment,
            behaviour,
            behaviourComment: behaviour_comment,
            occurenceTime: occurence_time,
            occurenceComment: occurence_comment,
            favoringFactors: favoring_factors,
            otherFavoringFactors: other_favoring_factors,
            effects,
          };
        }
      ),
    };
  });
};
