import "graphql-import-node";
import microCors from "micro-cors";
import { ApolloServer } from "apollo-server-micro";
import { send } from "micro";
import {
  getGeneralInformations,
  getIndicationsAndOtherDocumentedUsages,
  getContraindications,
  getSideEffects,
  getInteractions,
  getSpecialties,
  getCrushableSpecialties,
  getPharmacology,
  getProtocols
} from "./api";
import dotenv from "dotenv";
import typeDefs from "./schema.gql";
import {
  QueryGetGeneralInformationsArgs,
  QueryGetIndicationsAndOtherDocumentedUsagesArgs,
  QueryGetContraindicationsArgs,
  QueryGetSideEffectsArgs,
  QueryGetInteractionsArgs,
  FACILITY_SLUG_HEADER,
  FORMULARY_IDENTIFIER_HEADER,
  GuideContext,
  QueryGetSpecialtiesArgs,
  QueryGetCrushableSpecialtiesArgs,
} from "./types";

const FORWARDABLE_HEADERS = [FACILITY_SLUG_HEADER, FORMULARY_IDENTIFIER_HEADER];

dotenv.config();
const cors = microCors({
  allowHeaders: [
    "X-Requested-With",
    "Access-Control-Allow-Origin",
    "X-HTTP-Method-Override",
    "Content-Type",
    "Authorization",
    "Accept",
    ...FORWARDABLE_HEADERS,
  ],
});

const resolvers = {
  Query: {
    getGeneralInformations(
      parent,
      arg: QueryGetGeneralInformationsArgs,
      context
    ) {
      return getGeneralInformations(arg);
    },
    getIndicationsAndOtherDocumentedUsages(
      parent,
      arg: QueryGetIndicationsAndOtherDocumentedUsagesArgs,
      context
    ) {
      return getIndicationsAndOtherDocumentedUsages(arg);
    },
    getContraindications(parent, arg: QueryGetContraindicationsArgs, context) {
      return getContraindications(arg);
    },
    getSideEffects(parent, arg: QueryGetSideEffectsArgs, context) {
      return getSideEffects(arg);
    },
    getInteractions(parent, arg: QueryGetInteractionsArgs, context) {
      return getInteractions(arg);
    },
    getSpecialties(parent, arg: QueryGetSpecialtiesArgs, context) {
      return getSpecialties({ ...arg, context });
    },
    getCrushableSpecialties(parent, arg: QueryGetCrushableSpecialtiesArgs, context) {
      return getCrushableSpecialties(arg);
    },
    getPharmacology(parent, arg: QueryGetCrushableSpecialtiesArgs, context) {
      return getPharmacology(arg);
    },
    getProtocols(parent, arg: QueryGetCrushableSpecialtiesArgs, context) {
      return getProtocols(arg);
    }
  },
};

const context = ({ req }): GuideContext => {
  const mdbHeaders: any = {};
  FORWARDABLE_HEADERS.forEach((headerName) => {
    if (req.headers[headerName]) {
      mdbHeaders[headerName] = req.headers[headerName];
    }
  });
  return {
    mdbHeaders,
  };
};

const apolloServer = new ApolloServer({ typeDefs, resolvers, context });

module.exports = apolloServer.start().then(() => {
  const handler = apolloServer.createHandler();
  return cors((req, res) => {
    req.method === "OPTIONS" ? send(res, 200, "ok") : handler(req, res);
  });
});
