import { ApolloError } from "apollo-server-micro";
import { PososClient } from "@posos-tech/posos-client-nodejs";

export const generalInformationBody = /* GraphQL */ `
  query ($shortname: String) {
    drugs(shortname: $shortname) {
      form
      dose
      ingredients
      atc_parent {
        code
        label
      }
      atc {
        code
        label
      }
      conditions {
        icons {
          alt
          title
        }
      }
    }
  }
`;

export const indicationsAndOtherDocumentedUsagesBody = /* GraphQL */ `
  query ($shortname: String!) {
    drugs(shortname: $shortname) {
      form
      dose
      indications {
        disease
        nature_comments {
          name
        }
        level
        types
        smr
        text
        cim10 {
          code
          label
        }
      }
      unofficial_indications {
        label
        references
      }
    }
  }
`;

export const contraindicationsBody = /* GraphQL */ `
  query ($shortname: String!) {
    drugs(shortname: $shortname) {
      dose
      form
      contraindications {
        label
        level
        comment
        other_comment
        text
      }
    }
  }
`;

export const interactionsBody = /* GraphQL */ `
  query ($dci: String) {
    dci(dci: $dci) {
      interactions {
        nature
        with {
          dci
        }
        details {
          title
          nature
          instructions
          informations
          history
          bibliography
          source
        }
      }
    }
  }
`;

export const sideEffectsBody = /* GraphQL */ `
  query ($shortname: String!) {
    drugs(shortname: $shortname) {
      form
      dose
      side_effects_categories {
        category
        effects
        severity
        severity_category
        frequency
        frequency_string
        behaviour
        behaviour_comment
        occurence_time
        favoring_factors
        other_favoring_factors
      }
    }
  }
`;

export const specialtiesBody = /* GraphQL */ `
  query ($shortname: String!) {
    drugs(shortname: $shortname) {
      form
      dose
      formulary_specialties {
        cis
      }
      specialties {
        name
        cis
        crushable {
          uri
          recommandations
          intake
          stability
          pk_pd
          smpc_comment
          other_comments
        }
        excipients(known_effects: true) {
          name
        }
        presentations {
          presentation
          reimbursement
          price
        }
      }
    }
  }
`;

export const pharmacologyBody = /* GraphQL */ `
  query ($shortname: String!) {
    drugs(shortname: $shortname) {
      form
      dose
      pharmacodynamics {
        description
      }
      pharmacokinetics {
        description
      }
      etiology {
        intro
        inconsistently_sensitive {
          agent {
            name
            percentage
            category
          }
          comment
          text
        }
        usually_sensitive {
          agent {
            name
            percentage
            category
          }
          comment
          text
        }
        moderate_sensitive {
          agent {
            name
            percentage
            category
          }
          comment
          text
        }
        resistant {
          agent {
            name
            percentage
            category
          }
          comment
          text
        }
      }
    }
  }
`;

export const crushableSpecialtiesBody = /* GraphQL */ `
  query ($shortname: String!) {
    drugs(shortname: $shortname) {
      form
      dose
      specialties {
        name
        crushable {
          uri
          recommandations
          intake
          stability
          pk_pd
          smpc_comment
          other_comments
        }
      }
    }
  }
`;

export const protocolsBody = /* GraphQL */ `
  query ($shortname: String!) {
    drugs(shortname: $shortname) {
      form
      dose
      conditions {
        uri
        summary
        prescription {
          base_content
          validity_initial_hospital_prescription
          maximum_prescription_period
          prescription_reserved
          monitoring_during_treatment
          hospital_prescription
          exception_drugs
          archives
        }
        first_issuance {
          base_content
          prescription_support
          time_limit
          duration_treatment
        }
        renewal {
          base_content
          prescription_support
        }
      }
    }
  }
`;

export const callMedicalDb = async (
  body: string,
  variables: any,
  headers: any | null = null
): Promise<unknown> => {
  const POSOS_API_KEY = process.env.POSOS_API_KEY;
  const POSOS_API_URL = process.env.POSOS_API_URL;
  let client = new PososClient(POSOS_API_URL, POSOS_API_KEY);
  if (headers) {
    client = client.withHeaders(headers);
  }
  return client.v2.medicaldb.graphql(body, variables).catch((err) => {
    throw new ApolloError(
      `Error in medical-db request: ${JSON.stringify(err)}`
    );
  });
};
