jest.mock("../queryMedicalDb");
import { QueryGetContraindicationsArgs, DTOContraindicationsResponse } from "../types";
import { getContraindications } from "../api";
import { mocked } from "jest-mock";
import { callMedicalDb } from "../queryMedicalDb";
import {
    mockDolipraneContraindications,
    mockDolipraneContraindicationsDTOResponse,
} from "./mocks";

describe("getContraindications", () => {
  beforeEach(() => {
    jest.clearAllMocks();
  });

  it("should return error because no drug with this shortname", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve({
        drugs: [],
      })
    );
    const args: QueryGetContraindicationsArgs = {
      shortname: "this shortname doesn't exist",
    };

    expect(getContraindications(args)).rejects.toThrowError(
      "Error: There is no drug with this shortname."
    );
  });

  it("should return all contraindications", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve(
        mockDolipraneContraindicationsDTOResponse
      ) as unknown as DTOContraindicationsResponse
    );
    const args: QueryGetContraindicationsArgs = {
      shortname: "eprex",
    };

    const result = await getContraindications(args);

    expect(result).toEqual(mockDolipraneContraindications);
  });
});
