jest.mock("../queryMedicalDb");
import { QueryGetCrushableSpecialtiesArgs, DTOCrushableSpecialtiesResponse } from "../types";
import { getCrushableSpecialties } from "../api";
import { mocked } from "jest-mock";
import { callMedicalDb } from "../queryMedicalDb";
import {
    mockRisperdalCrushableSpecialties,
    mockRisperdalCrushableSpecialtiesDTOResponse,
} from "./mocks";

describe("getCrushableSpecialties", () => {
  beforeEach(() => {
    jest.clearAllMocks();
  });

  it("should return error because no drug with this shortname", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve({
        drugs: [],
      })
    );
    const args: QueryGetCrushableSpecialtiesArgs = {
      shortname: "this shortname doesn't exist",
    };

    expect(getCrushableSpecialties(args)).rejects.toThrowError(
      "Error: There is no drug with this shortname."
    );
  });

  it("should return all specialties", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve(
        mockRisperdalCrushableSpecialtiesDTOResponse
      ) as unknown as DTOCrushableSpecialtiesResponse
    );
    const args: QueryGetCrushableSpecialtiesArgs = {
      shortname: "risperdal",
    };

    const result = await getCrushableSpecialties(args);

    expect(result).toEqual(mockRisperdalCrushableSpecialties);
  });
});
