jest.mock("../queryMedicalDb");
import { QueryGetGeneralInformationsArgs, DTOGeneralInformationResponse } from "../types";
import { getGeneralInformations } from "../api";
import { mocked } from "jest-mock";
import { callMedicalDb } from "../queryMedicalDb";
import {
  mockEprexGeneralInformations,
  mockExprexGeneralInformationDTOResponse,
} from "./mocks";

describe("getGeneralInformations", () => {
  beforeEach(() => {
    jest.clearAllMocks();
  });

  it("should return error because no drug with this shortname", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve({
        drugs: [],
      })
    );
    const args: QueryGetGeneralInformationsArgs = {
      shortname: "this shortname doesn't exist",
    };

    expect(getGeneralInformations(args)).rejects.toThrowError(
      "Error: There is no drug with this shortname."
    );
  });

  it("should return all general informations", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve(
        mockExprexGeneralInformationDTOResponse
      ) as unknown as DTOGeneralInformationResponse
    );
    const args: QueryGetGeneralInformationsArgs = {
      shortname: "eprex",
    };

    const result = await getGeneralInformations(args);

    expect(result).toEqual(mockEprexGeneralInformations);
  });
});
