jest.mock("../queryMedicalDb");
import { QueryGetIndicationsAndOtherDocumentedUsagesArgs, DTOIndicationsAndOtherDocumentedUsages } from "../types";
import { getIndicationsAndOtherDocumentedUsages } from "../api";
import { mocked } from "jest-mock";
import { callMedicalDb } from "../queryMedicalDb";
import {
  mockAbilifyIndicationsAndOtherDocumentedUsages,
  mockAbilifyIndicationsAndOtherDocumentedUsagesDTOResponse,
} from "./mocks";

describe("getIndicationsAndOtherDocumentedUsages", () => {
  beforeEach(() => {
    jest.clearAllMocks();
  });

  it("should return error because no drug with this shortname", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve({
        drugs: [],
      })
    );
    const args: QueryGetIndicationsAndOtherDocumentedUsagesArgs = {
      shortname: "this shortname doesn't exist",
    };

    expect(getIndicationsAndOtherDocumentedUsages(args)).rejects.toThrowError(
      "Error: There is no drug with this shortname."
    );
  });

  it("should return all indications and other documented usages", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve(
        mockAbilifyIndicationsAndOtherDocumentedUsagesDTOResponse
      ) as unknown as DTOIndicationsAndOtherDocumentedUsages
    );
    const args: QueryGetIndicationsAndOtherDocumentedUsagesArgs = {
      shortname: "abilify",
    };

    const result = await getIndicationsAndOtherDocumentedUsages(args);

    expect(result).toEqual(
      mockAbilifyIndicationsAndOtherDocumentedUsages
    );
  });
});
