jest.mock("../queryMedicalDb");
import { QueryGetInteractionsArgs, DTOInteractionsResponse } from "../types";
import { getInteractions } from "../api";
import { mocked } from "jest-mock";
import { callMedicalDb } from "../queryMedicalDb";
import {
    mockParacetamolInteractions,
    mockParacetamolInteractionsDTOResponse,
} from "./mocks";

describe("getInteractions", () => {
  beforeEach(() => {
    jest.clearAllMocks();
  });

  it("should return error because no drug with this dci", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve({ dci: null})
    );
    const args: QueryGetInteractionsArgs = {
      dci: "this dci doesn't exist",
    };

    expect(getInteractions(args)).rejects.toThrowError(
      "Error: There is no drug with this dci."
    );
  });

  it("should return all interactions", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve(
        mockParacetamolInteractionsDTOResponse
      ) as unknown as DTOInteractionsResponse
    );
    const args: QueryGetInteractionsArgs = {
        dci: "paracétamol",
    };

    const result = await getInteractions(args);

    expect(result).toEqual(mockParacetamolInteractions);
  });
});
