jest.mock("../queryMedicalDb");
import { QueryGetPharmacologyArgs, DTOPharmacologyResponse } from "../types";
import { getPharmacology } from "../api";
import { mocked } from "jest-mock";
import { callMedicalDb } from "../queryMedicalDb";
import {
    mockBactrimPharmacology,
    mockBactrimPharmacologyDTOResponse,
} from "./mocks";

describe("getPharmacology", () => {
  beforeEach(() => {
    jest.clearAllMocks();
  });

  it("should return error because no drug with this shortname", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve({
        drugs: [],
      })
    );
    const args: QueryGetPharmacologyArgs = {
      shortname: "this shortname doesn't exist",
    };

    expect(getPharmacology(args)).rejects.toThrowError(
      "Error: There is no drug with this shortname."
    );
  });

  it("should return all specialties with their pharmacology", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve(
        mockBactrimPharmacologyDTOResponse
      ) as unknown as DTOPharmacologyResponse
    );
    const args: QueryGetPharmacologyArgs = {
      shortname: "bactrim",
    };

    const result = await getPharmacology(args);

    expect(result).toEqual(mockBactrimPharmacology);
  });
});
