jest.mock("../queryMedicalDb");
import { QueryGetProtocolsArgs, DTOProtocolsResponse } from "../types";
import { getProtocols } from "../api";
import { mocked } from "jest-mock";
import { callMedicalDb } from "../queryMedicalDb";
import {
    mockEprexProtocols,
    mockEprexProtocolsDTOResponse,
    mockDolipraneProtocolsDTOResponse,
} from "./mocks";

describe("getProtocols", () => {
  beforeEach(() => {
    jest.clearAllMocks();
  });

  it("should return error because no drug with this shortname", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve({
        drugs: [],
      })
    );
    const args: QueryGetProtocolsArgs = {
      shortname: "this shortname doesn't exist",
    };

    expect(getProtocols(args)).rejects.toThrowError(
      "Error: There is no drug with this shortname."
    );
  });

  it("should return no specialties because doliprane doesn't have protocols", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve(
        mockDolipraneProtocolsDTOResponse
      ) as unknown as DTOProtocolsResponse
    );
    const args: QueryGetProtocolsArgs = {
      shortname: "doliprane",
    };

    const result = await getProtocols(args);

    expect(result).toEqual([]);
  });

  it("should return all specialties with protocols", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve(
        mockEprexProtocolsDTOResponse
      ) as unknown as DTOProtocolsResponse
    );
    const args: QueryGetProtocolsArgs = {
      shortname: "eprex",
    };

    const result = await getProtocols(args);

    expect(result).toEqual(mockEprexProtocols);
  });
});
