jest.mock("../queryMedicalDb");
import { QueryGetSideEffectsArgs, DTOSideEffectsResponse } from "../types";
import { getSideEffects } from "../api";
import { mocked } from "jest-mock";
import { callMedicalDb } from "../queryMedicalDb";
import {
    mockDolipraneSideEffects,
    mockDolipraneSideEffectsDTOResponse,
} from "./mocks";

describe("getContraindications", () => {
  beforeEach(() => {
    jest.clearAllMocks();
  });

  it("should return error because no drug with this shortname", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve({
        drugs: [],
      })
    );
    const args: QueryGetSideEffectsArgs = {
      shortname: "this shortname doesn't exist",
    };

    expect(getSideEffects(args)).rejects.toThrowError(
      "Error: There is no drug with this shortname."
    );
  });

  it("should return all contraindications", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve(
        mockDolipraneSideEffectsDTOResponse
      ) as unknown as DTOSideEffectsResponse
    );
    const args: QueryGetSideEffectsArgs = {
      shortname: "doliprane",
    };

    const result = await getSideEffects(args);

    expect(result).toEqual(mockDolipraneSideEffects);
  });
});
