jest.mock("../queryMedicalDb");
import { QueryGetSpecialtiesArgs, DTOSpecialtiesResponse } from "../types";
import { getSpecialties } from "../api";
import { mocked } from "jest-mock";
import { callMedicalDb } from "../queryMedicalDb";
import {
    mockDolipraneSpecialties,
    mockDolipraneSpecialtiesDTOResponse,
} from "./mocks";

describe("getSpecialties", () => {
  beforeEach(() => {
    jest.clearAllMocks();
  });

  it("should return error because no drug with this shortname", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve({
        drugs: [],
      })
    );
    const args: QueryGetSpecialtiesArgs = {
      shortname: "this shortname doesn't exist",
    };

    expect(getSpecialties(args)).rejects.toThrowError(
      "Error: There is no drug with this shortname."
    );
  });

  it("should return all specialties", async () => {
    mocked(callMedicalDb).mockResolvedValue(
      Promise.resolve(
        mockDolipraneSpecialtiesDTOResponse
      ) as unknown as DTOSpecialtiesResponse
    );
    const args: QueryGetSpecialtiesArgs = {
      shortname: "doliprane",
    };

    const result = await getSpecialties(args);

    expect(result).toEqual(mockDolipraneSpecialties);
  });
});
