import { Crushable, Resistivity } from "./generated-graphql-types";

export const FORMULARY_IDENTIFIER_HEADER = "x-posos-formulary-identifier";
export const FACILITY_SLUG_HEADER = "x-posos-facility-slug";

export type GuideContext = {
  mdbHeaders: {
    [FORMULARY_IDENTIFIER_HEADER]: string;
    [FACILITY_SLUG_HEADER]: string;
  };
};

export type DTOGeneralInformationResponse = {
  drugs: {
    form?: string;
    dose?: string;
    ingredients: string[];
    atc_parent: {
      code: string;
      label: string;
    };
    atc: {
      code: string;
      label: string;
    };
    conditions: {
      icons: {
        alt: string;
        title: string;
      }[];
    };
  }[];
};

export type DTOIndicationsAndOtherDocumentedUsages = {
  drugs: {
    form?: string;
    dose?: string;
    indications: DTOIndication[];
    unofficial_indications: any[];
  }[];
};

export type DTOContraindicationsResponse = {
  drugs: {
    form?: string;
    dose?: string;
    contraindications: {
      label: string;
      level: string[];
      comment: string[] | null;
      other_comment: string[] | null;
      text: string[] | null;
    }[];
  }[];
};

export type DTOIndication = {
  disease: string;
  comments?: string[];
  nature_comments: {
    name: string;
  }[];
  level: string;
  types: string[];
  smr?: string;
  text: string;
  cim10: {
    code: string;
    label: string;
  }[];
};

export type DTOSideEffectsResponse = {
  drugs: {
    form?: string;
    dose?: string;
    side_effects_categories: {
      category: string | null;
      severity: string[];
      severity_category: string;
      frequency: number | null;
      frequency_string: string | null;
      frequency_comment: string | null;
      behaviour: string[];
      behaviour_comment: string | null;
      occurence_time: string[];
      occurence_comment: string | null;
      favoring_factors: string[];
      other_favoring_factors: string[];
      effects: string[];
    }[];
  }[];
};

export type DTOInteractionsResponse = {
  dci?: {
    interactions: {
      nature: string[];
      with: {
        dci: string;
      }[];
      details: {
        title: string;
        nature?: string;
        instructions?: string;
        informations: string[];
        history: string[];
        bibliography: string[];
        source?: string;
      };
    }[];
  };
};

export type DTOSpecialtiesResponse = {
  drugs: {
    form?: string;
    dose?: string;
    formulary_specialties:
      | {
          cis: string;
        }[]
      | null;
    specialties: DTOSpecialty[];
  }[];
};

export type DTOPharmacologyResponse = {
  drugs: {
    form?: string;
    dose?: string;
    pharmacodynamics: {
      description: string;
    }[];
    pharmacokinetics: {
      description: string;
    }[];
    etiology: DTOEtiology[];
  }[];
};

export type DTOEtiology = {
  intro: string;
  inconsistently_sensitive: Resistivity;
  usually_sensitive: Resistivity;
  moderate_sensitive: Resistivity;
  resistant: Resistivity;
};

export type DTOProtocolsResponse = {
  drugs: {
    form?: string;
    dose?: string;
    conditions?: DTOConditions;
  }[];
};

export type DTOConditions = {
  uri: string;
  summary?: string;
  prescription?: DTOPrescription;
  first_issuance?: DTOFirstInsuance;
  renewal?: DTORenewal;
};

export type DTOPrescription = {
  base_content?: string;
  validity_initial_hospital_prescription?: string;
  maximum_prescription_period?: string;
  prescription_reserved?: string;
  monitoring_during_treatment?: string;
  hospital_prescription?: string;
  exception_drugs?: string;
  archives?: string;
}

export type DTOFirstInsuance = {
  base_content?: string;
  prescription_support?: string;
  time_limit?: string;
  duration_treatment: string;
};

export type DTORenewal = {
  base_content?: string;
  prescription_support?: string;
};

export type DTOCrushableSpecialtiesResponse = {
  drugs: {
    form?: string;
    dose?: string;
    specialties: {
      name: string;
      crushable: Crushable | null;
    }[];
  }[];
};
export type DTOSpecialty = {
  name: string;
  cis: string;
  crushable: Crushable | null;
  excipients: {
    name: string;
  }[];
  presentations: {
    presentation: string;
    reimbursement?: string;
    price?: string;
  }[];
};
